cmd

package
v0.0.0-...-5bd24a5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 27, 2020 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var RootCmd = &cobra.Command{
	Use:   "lighthouse-keeper",
	Short: "Creates and pretty-prints lighthouse reports for a CI context",
}

Functions

func Execute

func Execute()

Execute is called by main to run the CLI

Types

This section is empty.

Directories

Path Synopsis
Package audit provides the `audit` command to create a lighthouse report.
Package audit provides the `audit` command to create a lighthouse report.
Package compare provides the `compare` command to perform a comparison of two lighthouse reports
Package compare provides the `compare` command to perform a comparison of two lighthouse reports
Package view provides the `view` command to print a lighthouse report
Package view provides the `view` command to print a lighthouse report

Jump to